@@ -28,11 +28,13 @@ const Geojsonvt = imports.geojsonvt.geojsonvt;
 const Location = imports.location;
 const Place = imports.place;
 const PlaceMarker = imports.placeMarker;
-const Service = imports.service;
 const Utils = imports.utils;
 const GeoJSONStyle = imports.geoJSONStyle;
 const MapView = imports.mapView;
 
+
+const TILE_SIZE = 256;
+
 const TileFeature = { POINT: 1,
                       LINESTRING: 2,
                       POLYGON: 3 };
@@ -46,7 +48,6 @@ class GeoJSONSource extends Champlain.TileSource {
         this._mapView = params.mapView;
         this._markerLayer = params.markerLayer;
         this._bbox = new Champlain.BoundingBox();
-        this._tileSize = Service.getService().tiles.street.tile_size;
     }
 
     get bbox() {
@@ -54,7 +55,7 @@ class GeoJSONSource extends Champlain.TileSource {
     }
 
     vfunc_get_tile_size() {
-        return this._tileSize;
+        return TILE_SIZE;
     }
 
     vfunc_get_max_zoom_level() {
@@ -85,7 +86,7 @@ class GeoJSONSource extends Champlain.TileSource {
                 this.next_source.fill_tile(tile);
         });
 
-        Mainloop.idle_add(() => this._renderTile(tile));
+        Mainloop.idle_add(() => this._renderTile(tile), tile);
     }
 
     _validate([lon, lat]) {
@@ -210,17 +211,17 @@ class GeoJSONSource extends Champlain.TileSource {
 
     parse(json) {
         this._parseInternal(json);
-        this._tileIndex = Geojsonvt.geojsonvt(json, { extent: this._tileSize,
+        this._tileIndex = Geojsonvt.geojsonvt(json, { extent: TILE_SIZE,
                                                       maxZoom: 20 });
         this._clampBBox();
     }
 
     _renderTile(tile) {
         let tileJSON = this._tileIndex.getTile(tile.zoom_level, tile.x, tile.y);
-        let content = new Clutter.Canvas({ width: this._tileSize,
-                                           height: this._tileSize });
-        tile.content = new Clutter.Actor({ width: this._tileSize,
-                                           height: this._tileSize,
+        let content = new Clutter.Canvas({ width: TILE_SIZE,
+                                           height: TILE_SIZE });
+        tile.content = new Clutter.Actor({ width: TILE_SIZE,
+                                           height: TILE_SIZE,
                                            content: content });
 
         content.connect('draw', (canvas, cr) => {
